Welcome to DjVue’s documentation! — DjVue 1.0 documentation

# Welcome to DjVue’s documentation!

## Overview

Note

This guide assumes intermediate knowledge of Django and DjangoRestFramework.

DjVue (deʒavy) is a front/back-end application which allow a simple and fast data interaction through RESTful API and standard HTTP communication using modern frameworks with an user friendly interface. DjVue will automatically build the tables reflecting the database using bootstrap design. DjVue also saves you the repetitive code writing for standard operations on the database such creations, updates and deletions and leave you the concern of writing just the serializers.

Contents:

- Installation
- Backend
  - Setup table
  - Tuning
    - Filtering
    - Sorting
    - Pagination
  - Forms
- Frontend
  - Setup
  - Table properties
  - Forms Component
- Common recipes
  - Allow CRUD operations only to some users or disable them at all
    - Creation
    - Detail
    - Update
    - Deletion
  - Add extra redirect buttons on table’s rows
  - Hide action buttons (both form and redirect)
  - Avoid using `SerializerMethodField`
- DjVue Serializer Fields
  - DVField
  - DVBooleanField
  - DVNullBooleanField
  - DVEmailField
  - DVRegexField
  - DVSlugField
  - DVURLField
  - DVUUIDField
  - DVIPAddressField
  - DVIntegerField
  - DVFloatField
  - DVDecimalField
  - DVDateTimeField
  - DVDateField
  - DVTimeField
  - DVDurationField
  - DVMultipleChoiceField
  - DVFilePathField
  - DVFileField
  - DVImageField
  - DVListField
  - DV_UnvalidatedField
  - DVDictField
  - DVHStoreField
  - DVJSONField
  - DVReadOnlyField
  - DVHiddenField
  - DVSerializerMethodField
  - DVModelField
  - DVCharField
  - DVChoiceField
  - DVAutocompletePrimaryKeyRelatedField

## Indices and tables

- Index

- Module Index

- Search Page